package org.jeecg.modules.okki.blog.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.okki.blog.service.IOkkiBlogService;
import org.jeecg.modules.okki.blog.entity.OkkiBlog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: 博客
 * @Author: jeecg-boot
 * @Date:   2024-05-09
 * @Version: V1.0
 */
@Api(tags="博客")
@RestController
@RequestMapping("/blog/okkiBlog")
@Slf4j
public class OkkiBlogController extends JeecgController<OkkiBlog, IOkkiBlogService> {
	@Autowired
	private IOkkiBlogService okkiBlogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param okkiBlog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "博客-分页列表查询")
	@ApiOperation(value="博客-分页列表查询", notes="博客-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OkkiBlog>> queryPageList(OkkiBlog okkiBlog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OkkiBlog> queryWrapper = QueryGenerator.initQueryWrapper(okkiBlog, req.getParameterMap());
		Page<OkkiBlog> page = new Page<OkkiBlog>(pageNo, pageSize);
		IPage<OkkiBlog> pageList = okkiBlogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param okkiBlog
	 * @return
	 */
	@AutoLog(value = "博客-添加")
	@ApiOperation(value="博客-添加", notes="博客-添加")
	@RequiresPermissions("blog:okki_blog:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OkkiBlog okkiBlog) {
		okkiBlogService.save(okkiBlog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param okkiBlog
	 * @return
	 */
	@AutoLog(value = "博客-编辑")
	@ApiOperation(value="博客-编辑", notes="博客-编辑")
	@RequiresPermissions("blog:okki_blog:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OkkiBlog okkiBlog) {
		okkiBlog.setStatus(0);
		okkiBlogService.updateById(okkiBlog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "博客-通过id删除")
	@ApiOperation(value="博客-通过id删除", notes="博客-通过id删除")
	@RequiresPermissions("blog:okki_blog:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		okkiBlogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "博客-批量删除")
	@ApiOperation(value="博客-批量删除", notes="博客-批量删除")
	@RequiresPermissions("blog:okki_blog:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.okkiBlogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "博客-通过id查询")
	@ApiOperation(value="博客-通过id查询", notes="博客-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OkkiBlog> queryById(@RequestParam(name="id",required=true) String id) {
		OkkiBlog okkiBlog = okkiBlogService.getById(id);
		if(okkiBlog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(okkiBlog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param okkiBlog
    */
    @RequiresPermissions("blog:okki_blog:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiBlog okkiBlog) {
        return super.exportXls(request, okkiBlog, OkkiBlog.class, "博客");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("blog:okki_blog:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiBlog.class);
    }

	 /**
	  * 变更状态
	  * @param okkiBlog
	  * @return
	  */
	 @PostMapping(value = "/status")
	 public Result<String> changeStatus(@RequestBody OkkiBlog okkiBlog) throws Exception {
		 boolean result = okkiBlogService.changeStatus(okkiBlog);
		 if (result) {
			 return Result.OK("操作成功");
		 }else {
			 return Result.error("操作失败");
		 }
	 }
}
